You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@logging.apache.org by gg...@apache.org on 2018/07/14 14:02:59 UTC

logging-log4j2 git commit: Param name matches other parts of Log4j.

Repository: logging-log4j2
Updated Branches:
  refs/heads/release-2.x 5ae9affa5 -> cfa53345b


Param name matches other parts of Log4j.

Project: http://git-wip-us.apache.org/repos/asf/logging-log4j2/repo
Commit: http://git-wip-us.apache.org/repos/asf/logging-log4j2/commit/cfa53345
Tree: http://git-wip-us.apache.org/repos/asf/logging-log4j2/tree/cfa53345
Diff: http://git-wip-us.apache.org/repos/asf/logging-log4j2/diff/cfa53345

Branch: refs/heads/release-2.x
Commit: cfa53345b7e6432b4470255efef9166299e2b209
Parents: 5ae9aff
Author: Gary Gregory <ga...@gmail.com>
Authored: Sat Jul 14 08:02:55 2018 -0600
Committer: Gary Gregory <ga...@gmail.com>
Committed: Sat Jul 14 08:02:55 2018 -0600

----------------------------------------------------------------------
 .../log4j/core/appender/RandomAccessFileManager.java  | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/logging-log4j2/blob/cfa53345/log4j-core/src/main/java/org/apache/logging/log4j/core/appender/RandomAccessFileManager.java
----------------------------------------------------------------------
diff --git a/log4j-core/src/main/java/org/apache/logging/log4j/core/appender/RandomAccessFileManager.java b/log4j-core/src/main/java/org/apache/logging/log4j/core/appender/RandomAccessFileManager.java
index 59f0df3..86e7e62 100644
--- a/log4j-core/src/main/java/org/apache/logging/log4j/core/appender/RandomAccessFileManager.java
+++ b/log4j-core/src/main/java/org/apache/logging/log4j/core/appender/RandomAccessFileManager.java
@@ -60,7 +60,7 @@ public class RandomAccessFileManager extends OutputStreamManager {
      * @param fileName The name of the file to manage.
      * @param append true if the file should be appended to, false if it should
      *            be overwritten.
      * @param isFlush true if the contents should be flushed to disk on every
      *            write
      * @param bufferSize The buffer size.
      * @param advertiseURI the URI to use when advertising the file
@@ -68,12 +68,12 @@ public class RandomAccessFileManager extends OutputStreamManager {
      * @param configuration The configuration.
      * @return A RandomAccessFileManager for the File.
      */
-    public static RandomAccessFileManager getFileManager(final String fileName, final boolean append,
-            final boolean isFlush, final int bufferSize, final String advertiseURI,
-            final Layout<? extends Serializable> layout, final Configuration configuration) {
-        return narrow(RandomAccessFileManager.class, getManager(fileName, new FactoryData(append,
-                isFlush, bufferSize, advertiseURI, layout, configuration), FACTORY));
-    }
+	public static RandomAccessFileManager getFileManager(final String fileName, final boolean append,
+			final boolean immediateFlush, final int bufferSize, final String advertiseURI,
+			final Layout<? extends Serializable> layout, final Configuration configuration) {
+		return narrow(RandomAccessFileManager.class, getManager(fileName,
+				new FactoryData(append, immediateFlush, bufferSize, advertiseURI, layout, configuration), FACTORY));
+	}
 
     public Boolean isEndOfBatch() {
         return isEndOfBatch.get();
@@ -60,7 +60,7 @@ public class RandomAccessFileManager extends OutputStreamManager {
      * @param append true if the file should be appended to, false if it should
      *            be overwritten.
-     * @param isFlush true if the contents should be flushed to disk on every
+     * @param immediateFlush true if the contents should be flushed to disk on every
      *            write
      * @param bufferSize The buffer size.